@@ -8,12 +8,11 @@ __author__ = 'MIT Data To AI Lab'
 __copyright__ = 'Copyright (c) 2018, MIT Data To AI Lab'
 __email__ = 'dailabmit@gmail.com'
 __license__ = 'MIT'
-__version__ = '0.2.2'
+__version__ = '0.3.0'
 
 from sdgym import benchmark, results, synthesizers
 from sdgym.benchmark import run
-from sdgym.data import load_dataset
-from sdgym.synthesizers import get_all_synthesizers
+from sdgym.datasets import load_dataset
 
 __all__ = [
     'benchmark',
@@ -21,5 +20,4 @@ __all__ = [
     'results',
     'run',
     'load_dataset',
-    'get_all_synthesizers',
 ]
